# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core_types.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63ore_types.proto\x12\x0bproto_types\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x99\x02\n\rCoreEventInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\x12\x15\n\rinvocation_id\x18\x05 \x01(\t\x12\x0b\n\x03pid\x18\x06 \x01(\x05\x12\x0e\n\x06thread\x18\x07 \x01(\t\x12&\n\x02ts\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x05\x65xtra\x18\t \x03(\x0b\x32%.proto_types.CoreEventInfo.ExtraEntry\x12\x10\n\x08\x63\x61tegory\x18\n \x01(\t\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n\x0cNodeRelation\x12\x10\n\x08\x64\x61tabase\x18\n \x01(\t\x12\x0e\n\x06schema\x18\x0b \x01(\t\x12\r\n\x05\x61lias\x18\x0c \x01(\t\x12\x15\n\rrelation_name\x18\r \x01(\t\"\x91\x02\n\x08NodeInfo\x12\x11\n\tnode_path\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x11\n\tunique_id\x18\x03 \x01(\t\x12\x15\n\rresource_type\x18\x04 \x01(\t\x12\x14\n\x0cmaterialized\x18\x05 \x01(\t\x12\x13\n\x0bnode_status\x18\x06 \x01(\t\x12\x17\n\x0fnode_started_at\x18\x07 \x01(\t\x12\x18\n\x10node_finished_at\x18\x08 \x01(\t\x12%\n\x04meta\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\rnode_relation\x18\n \x01(\x0b\x32\x19.proto_types.NodeRelation\"\x7f\n\rTimingInfoMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xd1\x01\n\x0cRunResultMsg\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12/\n\x0btiming_info\x18\x03 \x03(\x0b\x32\x1a.proto_types.TimingInfoMsg\x12\x0e\n\x06thread\x18\x04 \x01(\t\x12\x16\n\x0e\x65xecution_time\x18\x05 \x01(\x02\x12\x31\n\x10\x61\x64\x61pter_response\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0cnum_failures\x18\x07 \x01(\x05\"\\\n\nColumnType\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x1c\n\x14previous_column_type\x18\x02 \x01(\t\x12\x1b\n\x13\x63urrent_column_type\x18\x03 \x01(\t\"Y\n\x10\x43olumnConstraint\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x17\n\x0f\x63onstraint_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63onstraint_type\x18\x03 \x01(\t\"T\n\x0fModelConstraint\x12\x17\n\x0f\x63onstraint_name\x18\x01 \x01(\t\x12\x17\n\x0f\x63onstraint_type\x18\x02 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x03 \x03(\t\"9\n\x11MainReportVersion\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x13\n\x0blog_version\x18\x02 \x01(\x05\"n\n\x14MainReportVersionMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.MainReportVersion\"r\n\x0eMainReportArgs\x12\x33\n\x04\x61rgs\x18\x01 \x03(\x0b\x32%.proto_types.MainReportArgs.ArgsEntry\x1a+\n\tArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x11MainReportArgsMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.MainReportArgs\"+\n\x15MainTrackingUserState\x12\x12\n\nuser_state\x18\x01 \x01(\t\"v\n\x18MainTrackingUserStateMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.MainTrackingUserState\"5\n\x0fMergedFromState\x12\x12\n\nnum_merged\x18\x01 \x01(\x05\x12\x0e\n\x06sample\x18\x02 \x03(\t\"j\n\x12MergedFromStateMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.MergedFromState\"A\n\x14MissingProfileTarget\x12\x14\n\x0cprofile_name\x18\x01 \x01(\t\x12\x13\n\x0btarget_name\x18\x02 \x01(\t\"t\n\x17MissingProfileTargetMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.MissingProfileTarget\"(\n\x11InvalidOptionYAML\x12\x13\n\x0boption_name\x18\x01 \x01(\t\"n\n\x14InvalidOptionYAMLMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.InvalidOptionYAML\"!\n\x12LogDbtProjectError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"p\n\x15LogDbtProjectErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogDbtProjectError\"3\n\x12LogDbtProfileError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\x12\x10\n\x08profiles\x18\x02 \x03(\t\"p\n\x15LogDbtProfileErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogDbtProfileError\"!\n\x12StarterProjectPath\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"p\n\x15StarterProjectPathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.StarterProjectPath\"$\n\x15\x43onfigFolderDirectory\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"v\n\x18\x43onfigFolderDirectoryMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.ConfigFolderDirectory\"\'\n\x14NoSampleProfileFound\x12\x0f\n\x07\x61\x64\x61pter\x18\x01 \x01(\t\"t\n\x17NoSampleProfileFoundMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.NoSampleProfileFound\"6\n\x18ProfileWrittenWithSample\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"|\n\x1bProfileWrittenWithSampleMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.ProfileWrittenWithSample\"B\n$ProfileWrittenWithTargetTemplateYAML\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x94\x01\n\'ProfileWrittenWithTargetTemplateYAMLMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.proto_types.ProfileWrittenWithTargetTemplateYAML\"C\n%ProfileWrittenWithProjectTemplateYAML\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x96\x01\n(ProfileWrittenWithProjectTemplateYAMLMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.proto_types.ProfileWrittenWithProjectTemplateYAML\"\x12\n\x10SettingUpProfile\"l\n\x13SettingUpProfileMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.SettingUpProfile\"\x1c\n\x1aInvalidProfileTemplateYAML\"\x80\x01\n\x1dInvalidProfileTemplateYAMLMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.InvalidProfileTemplateYAML\"(\n\x18ProjectNameAlreadyExists\x12\x0c\n\x04name\x18\x01 \x01(\t\"|\n\x1bProjectNameAlreadyExistsMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.ProjectNameAlreadyExists\"K\n\x0eProjectCreated\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x10\n\x08\x64ocs_url\x18\x02 \x01(\t\x12\x11\n\tslack_url\x18\x03 \x01(\t\"h\n\x11ProjectCreatedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.ProjectCreated\"@\n\x1aPackageRedirectDeprecation\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"\x80\x01\n\x1dPackageRedirectDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.PackageRedirectDeprecation\"\x1f\n\x1dPackageInstallPathDeprecation\"\x86\x01\n PackageInstallPathDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.PackageInstallPathDeprecation\"H\n\x1b\x43onfigSourcePathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\x12\x10\n\x08\x65xp_path\x18\x02 \x01(\t\"\x82\x01\n\x1e\x43onfigSourcePathDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.ConfigSourcePathDeprecation\"F\n\x19\x43onfigDataPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\x12\x10\n\x08\x65xp_path\x18\x02 \x01(\t\"~\n\x1c\x43onfigDataPathDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.ConfigDataPathDeprecation\".\n\x17MetricAttributesRenamed\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\"z\n\x1aMetricAttributesRenamedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.MetricAttributesRenamed\"+\n\x17\x45xposureNameDeprecation\x12\x10\n\x08\x65xposure\x18\x01 \x01(\t\"z\n\x1a\x45xposureNameDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.ExposureNameDeprecation\"^\n\x13InternalDeprecation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x18\n\x10suggested_action\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"r\n\x16InternalDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.InternalDeprecation\"@\n\x1a\x45nvironmentVariableRenamed\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"\x80\x01\n\x1d\x45nvironmentVariableRenamedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.EnvironmentVariableRenamed\"3\n\x18\x43onfigLogPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\"|\n\x1b\x43onfigLogPathDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.ConfigLogPathDeprecation\"6\n\x1b\x43onfigTargetPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\"\x82\x01\n\x1e\x43onfigTargetPathDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.ConfigTargetPathDeprecation\"C\n\x16TestsConfigDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\x12\x10\n\x08\x65xp_path\x18\x02 \x01(\t\"x\n\x19TestsConfigDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.TestsConfigDeprecation\"\x1e\n\x1cProjectFlagsMovedDeprecation\"\x84\x01\n\x1fProjectFlagsMovedDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).proto_types.ProjectFlagsMovedDeprecation\"C\n\x1fSpacesInResourceNameDeprecation\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\t\"\x8a\x01\n\"SpacesInResourceNameDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.SpacesInResourceNameDeprecation\"i\n\"ResourceNamesWithSpacesDeprecation\x12\x1b\n\x13\x63ount_invalid_names\x18\x01 \x01(\x05\x12\x17\n\x0fshow_debug_hint\x18\x02 \x01(\x08\x12\r\n\x05level\x18\x03 \x01(\t\"\x90\x01\n%ResourceNamesWithSpacesDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.proto_types.ResourceNamesWithSpacesDeprecation\"_\n)PackageMaterializationOverrideDeprecation\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x1c\n\x14materialization_name\x18\x02 \x01(\t\"\x9e\x01\n,PackageMaterializationOverrideDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.proto_types.PackageMaterializationOverrideDeprecation\"#\n!SourceFreshnessProjectHooksNotRun\"\x8e\x01\n$SourceFreshnessProjectHooksNotRunMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..proto_types.SourceFreshnessProjectHooksNotRun\"V\n\x0f\x44\x65precatedModel\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65precation_date\x18\x03 \x01(\t\"j\n\x12\x44\x65precatedModelMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DeprecatedModel\"7\n\x12InputFileDiffError\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x0f\n\x07\x66ile_id\x18\x02 \x01(\t\"p\n\x15InputFileDiffErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.InputFileDiffError\"?\n\x14InvalidValueForField\x12\x12\n\nfield_name\x18\x01 \x01(\t\x12\x13\n\x0b\x66ield_value\x18\x02 \x01(\t\"t\n\x17InvalidValueForFieldMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.InvalidValueForField\"Q\n\x11ValidationWarning\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x12\n\nfield_name\x18\x02 \x01(\t\x12\x11\n\tnode_name\x18\x03 \x01(\t\"n\n\x14ValidationWarningMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.ValidationWarning\"!\n\x11ParsePerfInfoPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"n\n\x14ParsePerfInfoPathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.ParsePerfInfoPath\"1\n!PartialParsingErrorProcessingFile\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\"\x8e\x01\n$PartialParsingErrorProcessingFileMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..proto_types.PartialParsingErrorProcessingFile\"\x86\x01\n\x13PartialParsingError\x12?\n\x08\x65xc_info\x18\x01 \x03(\x0b\x32-.proto_types.PartialParsingError.ExcInfoEntry\x1a.\n\x0c\x45xcInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"r\n\x16PartialParsingErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.PartialParsingError\"\x1b\n\x19PartialParsingSkipParsing\"~\n\x1cPartialParsingSkipParsingMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.PartialParsingSkipParsing\"&\n\x14UnableToPartialParse\x12\x0e\n\x06reason\x18\x01 \x01(\t\"t\n\x17UnableToPartialParseMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.UnableToPartialParse\"f\n\x12StateCheckVarsHash\x12\x10\n\x08\x63hecksum\x18\x01 \x01(\t\x12\x0c\n\x04vars\x18\x02 \x01(\t\x12\x0f\n\x07profile\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\"p\n\x15StateCheckVarsHashMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.StateCheckVarsHash\"\x1a\n\x18PartialParsingNotEnabled\"|\n\x1bPartialParsingNotEnabledMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.PartialParsingNotEnabled\"C\n\x14ParsedFileLoadFailed\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"t\n\x17ParsedFileLoadFailedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.ParsedFileLoadFailed\"H\n\x15PartialParsingEnabled\x12\x0f\n\x07\x64\x65leted\x18\x01 \x01(\x05\x12\r\n\x05\x61\x64\x64\x65\x64\x18\x02 \x01(\x05\x12\x0f\n\x07\x63hanged\x18\x03 \x01(\x05\"v\n\x18PartialParsingEnabledMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.PartialParsingEnabled\"8\n\x12PartialParsingFile\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x11\n\toperation\x18\x02 \x01(\t\"p\n\x15PartialParsingFileMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.PartialParsingFile\"\xaf\x01\n\x1fInvalidDisabledTargetInTestNode\x12\x1b\n\x13resource_type_title\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x1a\n\x12original_file_path\x18\x03 \x01(\t\x12\x13\n\x0btarget_kind\x18\x04 \x01(\t\x12\x13\n\x0btarget_name\x18\x05 \x01(\t\x12\x16\n\x0etarget_package\x18\x06 \x01(\t\"\x8a\x01\n\"InvalidDisabledTargetInTestNodeMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.InvalidDisabledTargetInTestNode\"7\n\x18UnusedResourceConfigPath\x12\x1b\n\x13unused_config_paths\x18\x01 \x03(\t\"|\n\x1bUnusedResourceConfigPathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.UnusedResourceConfigPath\"3\n\rSeedIncreased\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"f\n\x10SeedIncreasedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.SeedIncreased\">\n\x18SeedExceedsLimitSamePath\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"|\n\x1bSeedExceedsLimitSamePathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.SeedExceedsLimitSamePath\"D\n\x1eSeedExceedsLimitAndPathChanged\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x88\x01\n!SeedExceedsLimitAndPathChangedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.SeedExceedsLimitAndPathChanged\"\\\n\x1fSeedExceedsLimitChecksumChanged\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rchecksum_name\x18\x03 \x01(\t\"\x8a\x01\n\"SeedExceedsLimitChecksumChangedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.SeedExceedsLimitChecksumChanged\"%\n\x0cUnusedTables\x12\x15\n\runused_tables\x18\x01 \x03(\t\"d\n\x0fUnusedTablesMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.UnusedTables\"\x87\x01\n\x17WrongResourceSchemaFile\x12\x12\n\npatch_name\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x1c\n\x14plural_resource_type\x18\x03 \x01(\t\x12\x10\n\x08yaml_key\x18\x04 \x01(\t\x12\x11\n\tfile_path\x18\x05 \x01(\t\"z\n\x1aWrongResourceSchemaFileMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.WrongResourceSchemaFile\"K\n\x10NoNodeForYamlKey\x12\x12\n\npatch_name\x18\x01 \x01(\t\x12\x10\n\x08yaml_key\x18\x02 \x01(\t\x12\x11\n\tfile_path\x18\x03 \x01(\t\"l\n\x13NoNodeForYamlKeyMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.NoNodeForYamlKey\"+\n\x15MacroNotFoundForPatch\x12\x12\n\npatch_name\x18\x01 \x01(\t\"v\n\x18MacroNotFoundForPatchMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.MacroNotFoundForPatch\"\xb8\x01\n\x16NodeNotFoundOrDisabled\x12\x1a\n\x12original_file_path\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x1b\n\x13resource_type_title\x18\x03 \x01(\t\x12\x13\n\x0btarget_name\x18\x04 \x01(\t\x12\x13\n\x0btarget_kind\x18\x05 \x01(\t\x12\x16\n\x0etarget_package\x18\x06 \x01(\t\x12\x10\n\x08\x64isabled\x18\x07 \x01(\t\"x\n\x19NodeNotFoundOrDisabledMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.NodeNotFoundOrDisabled\"H\n\x0fJinjaLogWarning\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"j\n\x12JinjaLogWarningMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.JinjaLogWarning\"E\n\x0cJinjaLogInfo\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"d\n\x0fJinjaLogInfoMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.JinjaLogInfo\"F\n\rJinjaLogDebug\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"f\n\x10JinjaLogDebugMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.JinjaLogDebug\"\xae\x01\n\x1eUnpinnedRefNewVersionAvailable\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x15\n\rref_node_name\x18\x02 \x01(\t\x12\x18\n\x10ref_node_package\x18\x03 \x01(\t\x12\x18\n\x10ref_node_version\x18\x04 \x01(\t\x12\x17\n\x0fref_max_version\x18\x05 \x01(\t\"\x88\x01\n!UnpinnedRefNewVersionAvailableMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.UnpinnedRefNewVersionAvailable\"\xc6\x01\n\x1cUpcomingReferenceDeprecation\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x19\n\x11ref_model_package\x18\x02 \x01(\t\x12\x16\n\x0eref_model_name\x18\x03 \x01(\t\x12\x19\n\x11ref_model_version\x18\x04 \x01(\t\x12 \n\x18ref_model_latest_version\x18\x05 \x01(\t\x12\"\n\x1aref_model_deprecation_date\x18\x06 \x01(\t\"\x84\x01\n\x1fUpcomingReferenceDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).proto_types.UpcomingReferenceDeprecation\"\xbd\x01\n\x13\x44\x65precatedReference\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x19\n\x11ref_model_package\x18\x02 \x01(\t\x12\x16\n\x0eref_model_name\x18\x03 \x01(\t\x12\x19\n\x11ref_model_version\x18\x04 \x01(\t\x12 \n\x18ref_model_latest_version\x18\x05 \x01(\t\x12\"\n\x1aref_model_deprecation_date\x18\x06 \x01(\t\"r\n\x16\x44\x65precatedReferenceMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.DeprecatedReference\"<\n$UnsupportedConstraintMaterialization\x12\x14\n\x0cmaterialized\x18\x01 \x01(\t\"\x94\x01\n\'UnsupportedConstraintMaterializationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.proto_types.UnsupportedConstraintMaterialization\"M\n\x14ParseInlineNodeError\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\"t\n\x17ParseInlineNodeErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.ParseInlineNodeError\"(\n\x19SemanticValidationFailure\x12\x0b\n\x03msg\x18\x02 \x01(\t\"~\n\x1cSemanticValidationFailureMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.SemanticValidationFailure\"\x8a\x03\n\x19UnversionedBreakingChange\x12\x18\n\x10\x62reaking_changes\x18\x01 \x03(\t\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x17\n\x0fmodel_file_path\x18\x03 \x01(\t\x12\"\n\x1a\x63ontract_enforced_disabled\x18\x04 \x01(\x08\x12\x17\n\x0f\x63olumns_removed\x18\x05 \x03(\t\x12\x34\n\x13\x63olumn_type_changes\x18\x06 \x03(\x0b\x32\x17.proto_types.ColumnType\x12I\n\"enforced_column_constraint_removed\x18\x07 \x03(\x0b\x32\x1d.proto_types.ColumnConstraint\x12G\n!enforced_model_constraint_removed\x18\x08 \x03(\x0b\x32\x1c.proto_types.ModelConstraint\x12\x1f\n\x17materialization_changed\x18\t \x03(\t\"~\n\x1cUnversionedBreakingChangeMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.UnversionedBreakingChange\"*\n\x14WarnStateTargetEqual\x12\x12\n\nstate_path\x18\x01 \x01(\t\"t\n\x17WarnStateTargetEqualMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.WarnStateTargetEqual\"%\n\x16\x46reshnessConfigProblem\x12\x0b\n\x03msg\x18\x01 \x01(\t\"x\n\x19\x46reshnessConfigProblemMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.FreshnessConfigProblem\"/\n\x1dGitSparseCheckoutSubdirectory\x12\x0e\n\x06subdir\x18\x01 \x01(\t\"\x86\x01\n GitSparseCheckoutSubdirectoryMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.GitSparseCheckoutSubdirectory\"/\n\x1bGitProgressCheckoutRevision\x12\x10\n\x08revision\x18\x01 \x01(\t\"\x82\x01\n\x1eGitProgressCheckoutRevisionMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.GitProgressCheckoutRevision\"4\n%GitProgressUpdatingExistingDependency\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"\x96\x01\n(GitProgressUpdatingExistingDependencyMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.proto_types.GitProgressUpdatingExistingDependency\".\n\x1fGitProgressPullingNewDependency\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"\x8a\x01\n\"GitProgressPullingNewDependencyMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.GitProgressPullingNewDependency\"\x1d\n\x0eGitNothingToDo\x12\x0b\n\x03sha\x18\x01 \x01(\t\"h\n\x11GitNothingToDoMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.GitNothingToDo\"E\n\x1fGitProgressUpdatedCheckoutRange\x12\x11\n\tstart_sha\x18\x01 \x01(\t\x12\x0f\n\x07\x65nd_sha\x18\x02 \x01(\t\"\x8a\x01\n\"GitProgressUpdatedCheckoutRangeMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.GitProgressUpdatedCheckoutRange\"*\n\x17GitProgressCheckedOutAt\x12\x0f\n\x07\x65nd_sha\x18\x01 \x01(\t\"z\n\x1aGitProgressCheckedOutAtMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.GitProgressCheckedOutAt\")\n\x1aRegistryProgressGETRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x80\x01\n\x1dRegistryProgressGETRequestMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.RegistryProgressGETRequest\"=\n\x1bRegistryProgressGETResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tresp_code\x18\x02 \x01(\x05\"\x82\x01\n\x1eRegistryProgressGETResponseMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.RegistryProgressGETResponse\"_\n\x1dSelectorReportInvalidSelector\x12\x17\n\x0fvalid_selectors\x18\x01 \x01(\t\x12\x13\n\x0bspec_method\x18\x02 \x01(\t\x12\x10\n\x08raw_spec\x18\x03 \x01(\t\"\x86\x01\n SelectorReportInvalidSelectorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.SelectorReportInvalidSelector\"\x15\n\x13\x44\x65psNoPackagesFound\"r\n\x16\x44\x65psNoPackagesFoundMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.DepsNoPackagesFound\"/\n\x17\x44\x65psStartPackageInstall\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\"z\n\x1a\x44\x65psStartPackageInstallMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.DepsStartPackageInstall\"\'\n\x0f\x44\x65psInstallInfo\x12\x14\n\x0cversion_name\x18\x01 \x01(\t\"j\n\x12\x44\x65psInstallInfoMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DepsInstallInfo\"-\n\x13\x44\x65psUpdateAvailable\x12\x16\n\x0eversion_latest\x18\x01 \x01(\t\"r\n\x16\x44\x65psUpdateAvailableMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.DepsUpdateAvailable\"\x0e\n\x0c\x44\x65psUpToDate\"d\n\x0f\x44\x65psUpToDateMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.DepsUpToDate\",\n\x14\x44\x65psListSubdirectory\x12\x14\n\x0csubdirectory\x18\x01 \x01(\t\"t\n\x17\x44\x65psListSubdirectoryMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.DepsListSubdirectory\".\n\x1a\x44\x65psNotifyUpdatesAvailable\x12\x10\n\x08packages\x18\x01 \x03(\t\"\x80\x01\n\x1d\x44\x65psNotifyUpdatesAvailableMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.DepsNotifyUpdatesAvailable\".\n\x1fRegistryIndexProgressGETRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x8a\x01\n\"RegistryIndexProgressGETRequestMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.RegistryIndexProgressGETRequest\"B\n RegistryIndexProgressGETResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tresp_code\x18\x02 \x01(\x05\"\x8c\x01\n#RegistryIndexProgressGETResponseMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.proto_types.RegistryIndexProgressGETResponse\"2\n\x1eRegistryResponseUnexpectedType\x12\x10\n\x08response\x18\x01 \x01(\t\"\x88\x01\n!RegistryResponseUnexpectedTypeMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.RegistryResponseUnexpectedType\"2\n\x1eRegistryResponseMissingTopKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\x88\x01\n!RegistryResponseMissingTopKeysMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.RegistryResponseMissingTopKeys\"5\n!RegistryResponseMissingNestedKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\x8e\x01\n$RegistryResponseMissingNestedKeysMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..proto_types.RegistryResponseMissingNestedKeys\"3\n\x1fRegistryResponseExtraNestedKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\x8a\x01\n\"RegistryResponseExtraNestedKeysMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.RegistryResponseExtraNestedKeys\"(\n\x18\x44\x65psSetDownloadDirectory\x12\x0c\n\x04path\x18\x01 \x01(\t\"|\n\x1b\x44\x65psSetDownloadDirectoryMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.DepsSetDownloadDirectory\"-\n\x0c\x44\x65psUnpinned\x12\x10\n\x08revision\x18\x01 \x01(\t\x12\x0b\n\x03git\x18\x02 \x01(\t\"d\n\x0f\x44\x65psUnpinnedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.DepsUnpinned\"/\n\x1bNoNodesForSelectionCriteria\x12\x10\n\x08spec_raw\x18\x01 \x01(\t\"\x82\x01\n\x1eNoNodesForSelectionCriteriaMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.NoNodesForSelectionCriteria\")\n\x10\x44\x65psLockUpdating\x12\x15\n\rlock_filepath\x18\x01 \x01(\t\"l\n\x13\x44\x65psLockUpdatingMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.DepsLockUpdating\"R\n\x0e\x44\x65psAddPackage\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x19\n\x11packages_filepath\x18\x03 \x01(\t\"h\n\x11\x44\x65psAddPackageMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.DepsAddPackage\"\xa7\x01\n\x19\x44\x65psFoundDuplicatePackage\x12S\n\x0fremoved_package\x18\x01 \x03(\x0b\x32:.proto_types.DepsFoundDuplicatePackage.RemovedPackageEntry\x1a\x35\n\x13RemovedPackageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x1c\x44\x65psFoundDuplicatePackageMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.DepsFoundDuplicatePackage\"$\n\x12\x44\x65psVersionMissing\x12\x0e\n\x06source\x18\x01 \x01(\t\"p\n\x15\x44\x65psVersionMissingMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.DepsVersionMissing\"/\n\x17\x44\x65psScrubbedPackageName\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\"z\n\x1a\x44\x65psScrubbedPackageNameMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.DepsScrubbedPackageName\"*\n\x1bRunningOperationCaughtError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\x82\x01\n\x1eRunningOperationCaughtErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.RunningOperationCaughtError\"\x11\n\x0f\x43ompileComplete\"j\n\x12\x43ompileCompleteMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.CompileComplete\"\x18\n\x16\x46reshnessCheckComplete\"x\n\x19\x46reshnessCheckCompleteMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.FreshnessCheckComplete\"\x1c\n\nSeedHeader\x12\x0e\n\x06header\x18\x01 \x01(\t\"`\n\rSeedHeaderMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.SeedHeader\"]\n\x12SQLRunnerException\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x02 \x01(\t\x12(\n\tnode_info\x18\x03 \x01(\x0b\x32\x15.proto_types.NodeInfo\"p\n\x15SQLRunnerExceptionMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.SQLRunnerException\"\xa8\x01\n\rLogTestResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\x12\n\nnum_models\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x14\n\x0cnum_failures\x18\x07 \x01(\x05\"f\n\x10LogTestResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.LogTestResult\"k\n\x0cLogStartLine\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"d\n\x0fLogStartLineMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.LogStartLine\"\x95\x01\n\x0eLogModelResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\"h\n\x11LogModelResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.LogModelResult\"\x92\x02\n\x11LogSnapshotResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x34\n\x03\x63\x66g\x18\x07 \x03(\x0b\x32\'.proto_types.LogSnapshotResult.CfgEntry\x12\x16\n\x0eresult_message\x18\x08 \x01(\t\x1a*\n\x08\x43\x66gEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x14LogSnapshotResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.LogSnapshotResult\"\xb9\x01\n\rLogSeedResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x16\n\x0eresult_message\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x0e\n\x06schema\x18\x07 \x01(\t\x12\x10\n\x08relation\x18\x08 \x01(\t\"f\n\x10LogSeedResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.LogSeedResult\"\xad\x01\n\x12LogFreshnessResult\x12\x0e\n\x06status\x18\x01 \x01(\t\x12(\n\tnode_info\x18\x02 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x05 \x01(\x02\x12\x13\n\x0bsource_name\x18\x06 \x01(\t\x12\x12\n\ntable_name\x18\x07 \x01(\t\"p\n\x15LogFreshnessResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogFreshnessResult\"\x98\x01\n\x11LogNodeNoOpResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\"n\n\x14LogNodeNoOpResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.LogNodeNoOpResult\"\"\n\rLogCancelLine\x12\x11\n\tconn_name\x18\x01 \x01(\t\"f\n\x10LogCancelLineMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.LogCancelLine\"\x1f\n\x0f\x44\x65\x66\x61ultSelector\x12\x0c\n\x04name\x18\x01 \x01(\t\"j\n\x12\x44\x65\x66\x61ultSelectorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DefaultSelector\"5\n\tNodeStart\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"^\n\x0cNodeStartMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.proto_types.NodeStart\"g\n\x0cNodeFinished\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12-\n\nrun_result\x18\x02 \x01(\x0b\x32\x19.proto_types.RunResultMsg\"d\n\x0fNodeFinishedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.NodeFinished\"+\n\x1bQueryCancelationUnsupported\x12\x0c\n\x04type\x18\x01 \x01(\t\"\x82\x01\n\x1eQueryCancelationUnsupportedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.QueryCancelationUnsupported\"O\n\x0f\x43oncurrencyLine\x12\x13\n\x0bnum_threads\x18\x01 \x01(\x05\x12\x13\n\x0btarget_name\x18\x02 \x01(\t\x12\x12\n\nnode_count\x18\x03 \x01(\x05\"j\n\x12\x43oncurrencyLineMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.ConcurrencyLine\"E\n\x19WritingInjectedSQLForNode\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"~\n\x1cWritingInjectedSQLForNodeMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.WritingInjectedSQLForNode\"9\n\rNodeCompiling\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"f\n\x10NodeCompilingMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.NodeCompiling\"9\n\rNodeExecuting\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"f\n\x10NodeExecutingMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.NodeExecuting\"m\n\x10LogHookStartLine\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tstatement\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"l\n\x13LogHookStartLineMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.LogHookStartLine\"\x93\x01\n\x0eLogHookEndLine\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tstatement\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\"h\n\x11LogHookEndLineMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.LogHookEndLine\"\x93\x01\n\x0fSkippingDetails\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x11\n\tnode_name\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x05\x12\r\n\x05total\x18\x06 \x01(\x05\"j\n\x12SkippingDetailsMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.SkippingDetails\"\r\n\x0bNothingToDo\"b\n\x0eNothingToDoMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.NothingToDo\",\n\x1dRunningOperationUncaughtError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\x86\x01\n RunningOperationUncaughtErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.RunningOperationUncaughtError\"\x93\x01\n\x0c\x45ndRunResult\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.proto_types.RunResultMsg\x12\x14\n\x0c\x65lapsed_time\x18\x02 \x01(\x02\x12\x30\n\x0cgenerated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07success\x18\x04 \x01(\x08\"d\n\x0f\x45ndRunResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.EndRunResult\"\x11\n\x0fNoNodesSelected\"j\n\x12NoNodesSelectedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.NoNodesSelected\"w\n\x10\x43ommandCompleted\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x30\n\x0c\x63ompleted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x65lapsed\x18\x04 \x01(\x02\"l\n\x13\x43ommandCompletedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.CommandCompleted\"k\n\x08ShowNode\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x0f\n\x07preview\x18\x02 \x01(\t\x12\x11\n\tis_inline\x18\x03 \x01(\x08\x12\x15\n\routput_format\x18\x04 \x01(\t\x12\x11\n\tunique_id\x18\x05 \x01(\t\"\\\n\x0bShowNodeMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12#\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x15.proto_types.ShowNode\"p\n\x0c\x43ompiledNode\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x10\n\x08\x63ompiled\x18\x02 \x01(\t\x12\x11\n\tis_inline\x18\x03 \x01(\x08\x12\x15\n\routput_format\x18\x04 \x01(\t\x12\x11\n\tunique_id\x18\x05 \x01(\t\"d\n\x0f\x43ompiledNodeMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.CompiledNode\"b\n\x17\x43\x61tchableExceptionOnRun\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"z\n\x1a\x43\x61tchableExceptionOnRunMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.CatchableExceptionOnRun\"_\n\x12InternalErrorOnRun\x12\x12\n\nbuild_path\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12(\n\tnode_info\x18\x03 \x01(\x0b\x32\x15.proto_types.NodeInfo\"p\n\x15InternalErrorOnRunMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.InternalErrorOnRun\"u\n\x15GenericExceptionOnRun\x12\x12\n\nbuild_path\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x0b\n\x03\x65xc\x18\x03 \x01(\t\x12(\n\tnode_info\x18\x04 \x01(\x0b\x32\x15.proto_types.NodeInfo\"v\n\x18GenericExceptionOnRunMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.GenericExceptionOnRun\"N\n\x1aNodeConnectionReleaseError\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"\x80\x01\n\x1dNodeConnectionReleaseErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.NodeConnectionReleaseError\"\x1f\n\nFoundStats\x12\x11\n\tstat_line\x18\x01 \x01(\t\"`\n\rFoundStatsMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.FoundStats\"\x17\n\x15MainKeyboardInterrupt\"v\n\x18MainKeyboardInterruptMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.MainKeyboardInterrupt\"#\n\x14MainEncounteredError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"t\n\x17MainEncounteredErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.MainEncounteredError\"%\n\x0eMainStackTrace\x12\x13\n\x0bstack_trace\x18\x01 \x01(\t\"h\n\x11MainStackTraceMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.MainStackTrace\"p\n\x13TimingInfoCollected\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12/\n\x0btiming_info\x18\x02 \x01(\x0b\x32\x1a.proto_types.TimingInfoMsg\"r\n\x16TimingInfoCollectedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.TimingInfoCollected\"&\n\x12LogDebugStackTrace\x12\x10\n\x08\x65xc_info\x18\x01 \x01(\t\"p\n\x15LogDebugStackTraceMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogDebugStackTrace\"\x1e\n\x0e\x43heckCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"h\n\x11\x43heckCleanPathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.CheckCleanPath\" \n\x10\x43onfirmCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"l\n\x13\x43onfirmCleanPathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.ConfirmCleanPath\"\"\n\x12ProtectedCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"p\n\x15ProtectedCleanPathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.ProtectedCleanPath\"\x14\n\x12\x46inishedCleanPaths\"p\n\x15\x46inishedCleanPathsMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.FinishedCleanPaths\"5\n\x0bOpenCommand\x12\x10\n\x08open_cmd\x18\x01 \x01(\t\x12\x14\n\x0cprofiles_dir\x18\x02 \x01(\t\"b\n\x0eOpenCommandMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.OpenCommand\"0\n\x0fServingDocsPort\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"j\n\x12ServingDocsPortMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.ServingDocsPort\"%\n\x15ServingDocsAccessInfo\x12\x0c\n\x04port\x18\x01 \x01(\t\"v\n\x18ServingDocsAccessInfoMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.ServingDocsAccessInfo\"\x15\n\x13ServingDocsExitInfo\"r\n\x16ServingDocsExitInfoMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.ServingDocsExitInfo\"t\n\x10RunResultWarning\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12(\n\tnode_info\x18\x04 \x01(\x0b\x32\x15.proto_types.NodeInfo\"l\n\x13RunResultWarningMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.RunResultWarning\"t\n\x10RunResultFailure\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12(\n\tnode_info\x18\x04 \x01(\x0b\x32\x15.proto_types.NodeInfo\"l\n\x13RunResultFailureMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.RunResultFailure\"k\n\tStatsLine\x12\x30\n\x05stats\x18\x01 \x03(\x0b\x32!.proto_types.StatsLine.StatsEntry\x1a,\n\nStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"^\n\x0cStatsLineMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.proto_types.StatsLine\"G\n\x0eRunResultError\x12\x0b\n\x03msg\x18\x01 \x01(\t\x12(\n\tnode_info\x18\x02 \x01(\x0b\x32\x15.proto_types.NodeInfo\"h\n\x11RunResultErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.RunResultError\"S\n\x17RunResultErrorNoMessage\x12\x0e\n\x06status\x18\x01 \x01(\t\x12(\n\tnode_info\x18\x02 \x01(\x0b\x32\x15.proto_types.NodeInfo\"z\n\x1aRunResultErrorNoMessageMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.RunResultErrorNoMessage\"I\n\x0fSQLCompiledPath\x12\x0c\n\x04path\x18\x01 \x01(\t\x12(\n\tnode_info\x18\x02 \x01(\x0b\x32\x15.proto_types.NodeInfo\"j\n\x12SQLCompiledPathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.SQLCompiledPath\"W\n\x14\x43heckNodeTestFailure\x12\x15\n\rrelation_name\x18\x01 \x01(\t\x12(\n\tnode_info\x18\x02 \x01(\x0b\x32\x15.proto_types.NodeInfo\"t\n\x17\x43heckNodeTestFailureMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.CheckNodeTestFailure\"W\n\x0f\x45ndOfRunSummary\x12\x12\n\nnum_errors\x18\x01 \x01(\x05\x12\x14\n\x0cnum_warnings\x18\x02 \x01(\x05\x12\x1a\n\x12keyboard_interrupt\x18\x03 \x01(\x08\"j\n\x12\x45ndOfRunSummaryMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.EndOfRunSummary\"U\n\x13LogSkipBecauseError\x12\x0e\n\x06schema\x18\x01 \x01(\t\x12\x10\n\x08relation\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"r\n\x16LogSkipBecauseErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.LogSkipBecauseError\"\x14\n\x12\x45nsureGitInstalled\"p\n\x15\x45nsureGitInstalledMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.EnsureGitInstalled\"\x1a\n\x18\x44\x65psCreatingLocalSymlink\"|\n\x1b\x44\x65psCreatingLocalSymlinkMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.DepsCreatingLocalSymlink\"\x19\n\x17\x44\x65psSymlinkNotAvailable\"z\n\x1a\x44\x65psSymlinkNotAvailableMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.DepsSymlinkNotAvailable\"\x11\n\x0f\x44isableTracking\"j\n\x12\x44isableTrackingMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DisableTracking\"\x1e\n\x0cSendingEvent\x12\x0e\n\x06kwargs\x18\x01 \x01(\t\"d\n\x0fSendingEventMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.SendingEvent\"\x12\n\x10SendEventFailure\"l\n\x13SendEventFailureMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.SendEventFailure\"\r\n\x0b\x46lushEvents\"b\n\x0e\x46lushEventsMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.FlushEvents\"\x14\n\x12\x46lushEventsFailure\"p\n\x15\x46lushEventsFailureMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.FlushEventsFailure\"-\n\x19TrackingInitializeFailure\x12\x10\n\x08\x65xc_info\x18\x01 \x01(\t\"~\n\x1cTrackingInitializeFailureMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.TrackingInitializeFailure\"P\n\x17RunResultWarningMessage\x12\x0b\n\x03msg\x18\x01 \x01(\t\x12(\n\tnode_info\x18\x02 \x01(\x0b\x32\x15.proto_types.NodeInfo\"z\n\x1aRunResultWarningMessageMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.RunResultWarningMessage\"\x1a\n\x0b\x44\x65\x62ugCmdOut\x12\x0b\n\x03msg\x18\x01 \x01(\t\"b\n\x0e\x44\x65\x62ugCmdOutMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.DebugCmdOut\"\x1d\n\x0e\x44\x65\x62ugCmdResult\x12\x0b\n\x03msg\x18\x01 \x01(\t\"h\n\x11\x44\x65\x62ugCmdResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.DebugCmdResult\"\x19\n\nListCmdOut\x12\x0b\n\x03msg\x18\x01 \x01(\t\"`\n\rListCmdOutMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.ListCmdOut\"\xec\x01\n\x0eResourceReport\x12\x14\n\x0c\x63ommand_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ommand_success\x18\x03 \x01(\x08\x12\x1f\n\x17\x63ommand_wall_clock_time\x18\x04 \x01(\x02\x12\x19\n\x11process_user_time\x18\x05 \x01(\x02\x12\x1b\n\x13process_kernel_time\x18\x06 \x01(\x02\x12\x1b\n\x13process_mem_max_rss\x18\x07 \x01(\x03\x12\x19\n\x11process_in_blocks\x18\x08 \x01(\x03\x12\x1a\n\x12process_out_blocks\x18\t \x01(\x03\"h\n\x11ResourceReportMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.ResourceReportb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_COREEVENTINFO_EXTRAENTRY']._options = None
  _globals['_COREEVENTINFO_EXTRAENTRY']._serialized_options = b'8\001'
  _globals['_MAINREPORTARGS_ARGSENTRY']._options = None
  _globals['_MAINREPORTARGS_ARGSENTRY']._serialized_options = b'8\001'
  _globals['_PARTIALPARSINGERROR_EXCINFOENTRY']._options = None
  _globals['_PARTIALPARSINGERROR_EXCINFOENTRY']._serialized_options = b'8\001'
  _globals['_DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY']._options = None
  _globals['_DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY']._serialized_options = b'8\001'
  _globals['_LOGSNAPSHOTRESULT_CFGENTRY']._options = None
  _globals['_LOGSNAPSHOTRESULT_CFGENTRY']._serialized_options = b'8\001'
  _globals['_STATSLINE_STATSENTRY']._options = None
  _globals['_STATSLINE_STATSENTRY']._serialized_options = b'8\001'
  _globals['_COREEVENTINFO']._serialized_start=97
  _globals['_COREEVENTINFO']._serialized_end=378
  _globals['_COREEVENTINFO_EXTRAENTRY']._serialized_start=334
  _globals['_COREEVENTINFO_EXTRAENTRY']._serialized_end=378
  _globals['_NODERELATION']._serialized_start=380
  _globals['_NODERELATION']._serialized_end=466
  _globals['_NODEINFO']._serialized_start=469
  _globals['_NODEINFO']._serialized_end=742
  _globals['_TIMINGINFOMSG']._serialized_start=744
  _globals['_TIMINGINFOMSG']._serialized_end=871
  _globals['_RUNRESULTMSG']._serialized_start=874
  _globals['_RUNRESULTMSG']._serialized_end=1083
  _globals['_COLUMNTYPE']._serialized_start=1085
  _globals['_COLUMNTYPE']._serialized_end=1177
  _globals['_COLUMNCONSTRAINT']._serialized_start=1179
  _globals['_COLUMNCONSTRAINT']._serialized_end=1268
  _globals['_MODELCONSTRAINT']._serialized_start=1270
  _globals['_MODELCONSTRAINT']._serialized_end=1354
  _globals['_MAINREPORTVERSION']._serialized_start=1356
  _globals['_MAINREPORTVERSION']._serialized_end=1413
  _globals['_MAINREPORTVERSIONMSG']._serialized_start=1415
  _globals['_MAINREPORTVERSIONMSG']._serialized_end=1525
  _globals['_MAINREPORTARGS']._serialized_start=1527
  _globals['_MAINREPORTARGS']._serialized_end=1641
  _globals['_MAINREPORTARGS_ARGSENTRY']._serialized_start=1598
  _globals['_MAINREPORTARGS_ARGSENTRY']._serialized_end=1641
  _globals['_MAINREPORTARGSMSG']._serialized_start=1643
  _globals['_MAINREPORTARGSMSG']._serialized_end=1747
  _globals['_MAINTRACKINGUSERSTATE']._serialized_start=1749
  _globals['_MAINTRACKINGUSERSTATE']._serialized_end=1792
  _globals['_MAINTRACKINGUSERSTATEMSG']._serialized_start=1794
  _globals['_MAINTRACKINGUSERSTATEMSG']._serialized_end=1912
  _globals['_MERGEDFROMSTATE']._serialized_start=1914
  _globals['_MERGEDFROMSTATE']._serialized_end=1967
  _globals['_MERGEDFROMSTATEMSG']._serialized_start=1969
  _globals['_MERGEDFROMSTATEMSG']._serialized_end=2075
  _globals['_MISSINGPROFILETARGET']._serialized_start=2077
  _globals['_MISSINGPROFILETARGET']._serialized_end=2142
  _globals['_MISSINGPROFILETARGETMSG']._serialized_start=2144
  _globals['_MISSINGPROFILETARGETMSG']._serialized_end=2260
  _globals['_INVALIDOPTIONYAML']._serialized_start=2262
  _globals['_INVALIDOPTIONYAML']._serialized_end=2302
  _globals['_INVALIDOPTIONYAMLMSG']._serialized_start=2304
  _globals['_INVALIDOPTIONYAMLMSG']._serialized_end=2414
  _globals['_LOGDBTPROJECTERROR']._serialized_start=2416
  _globals['_LOGDBTPROJECTERROR']._serialized_end=2449
  _globals['_LOGDBTPROJECTERRORMSG']._serialized_start=2451
  _globals['_LOGDBTPROJECTERRORMSG']._serialized_end=2563
  _globals['_LOGDBTPROFILEERROR']._serialized_start=2565
  _globals['_LOGDBTPROFILEERROR']._serialized_end=2616
  _globals['_LOGDBTPROFILEERRORMSG']._serialized_start=2618
  _globals['_LOGDBTPROFILEERRORMSG']._serialized_end=2730
  _globals['_STARTERPROJECTPATH']._serialized_start=2732
  _globals['_STARTERPROJECTPATH']._serialized_end=2765
  _globals['_STARTERPROJECTPATHMSG']._serialized_start=2767
  _globals['_STARTERPROJECTPATHMSG']._serialized_end=2879
  _globals['_CONFIGFOLDERDIRECTORY']._serialized_start=2881
  _globals['_CONFIGFOLDERDIRECTORY']._serialized_end=2917
  _globals['_CONFIGFOLDERDIRECTORYMSG']._serialized_start=2919
  _globals['_CONFIGFOLDERDIRECTORYMSG']._serialized_end=3037
  _globals['_NOSAMPLEPROFILEFOUND']._serialized_start=3039
  _globals['_NOSAMPLEPROFILEFOUND']._serialized_end=3078
  _globals['_NOSAMPLEPROFILEFOUNDMSG']._serialized_start=3080
  _globals['_NOSAMPLEPROFILEFOUNDMSG']._serialized_end=3196
  _globals['_PROFILEWRITTENWITHSAMPLE']._serialized_start=3198
  _globals['_PROFILEWRITTENWITHSAMPLE']._serialized_end=3252
  _globals['_PROFILEWRITTENWITHSAMPLEMSG']._serialized_start=3254
  _globals['_PROFILEWRITTENWITHSAMPLEMSG']._serialized_end=3378
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAML']._serialized_start=3380
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAML']._serialized_end=3446
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAMLMSG']._serialized_start=3449
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAMLMSG']._serialized_end=3597
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAML']._serialized_start=3599
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAML']._serialized_end=3666
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAMLMSG']._serialized_start=3669
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAMLMSG']._serialized_end=3819
  _globals['_SETTINGUPPROFILE']._serialized_start=3821
  _globals['_SETTINGUPPROFILE']._serialized_end=3839
  _globals['_SETTINGUPPROFILEMSG']._serialized_start=3841
  _globals['_SETTINGUPPROFILEMSG']._serialized_end=3949
  _globals['_INVALIDPROFILETEMPLATEYAML']._serialized_start=3951
  _globals['_INVALIDPROFILETEMPLATEYAML']._serialized_end=3979
  _globals['_INVALIDPROFILETEMPLATEYAMLMSG']._serialized_start=3982
  _globals['_INVALIDPROFILETEMPLATEYAMLMSG']._serialized_end=4110
  _globals['_PROJECTNAMEALREADYEXISTS']._serialized_start=4112
  _globals['_PROJECTNAMEALREADYEXISTS']._serialized_end=4152
  _globals['_PROJECTNAMEALREADYEXISTSMSG']._serialized_start=4154
  _globals['_PROJECTNAMEALREADYEXISTSMSG']._serialized_end=4278
  _globals['_PROJECTCREATED']._serialized_start=4280
  _globals['_PROJECTCREATED']._serialized_end=4355
  _globals['_PROJECTCREATEDMSG']._serialized_start=4357
  _globals['_PROJECTCREATEDMSG']._serialized_end=4461
  _globals['_PACKAGEREDIRECTDEPRECATION']._serialized_start=4463
  _globals['_PACKAGEREDIRECTDEPRECATION']._serialized_end=4527
  _globals['_PACKAGEREDIRECTDEPRECATIONMSG']._serialized_start=4530
  _globals['_PACKAGEREDIRECTDEPRECATIONMSG']._serialized_end=4658
  _globals['_PACKAGEINSTALLPATHDEPRECATION']._serialized_start=4660
  _globals['_PACKAGEINSTALLPATHDEPRECATION']._serialized_end=4691
  _globals['_PACKAGEINSTALLPATHDEPRECATIONMSG']._serialized_start=4694
  _globals['_PACKAGEINSTALLPATHDEPRECATIONMSG']._serialized_end=4828
  _globals['_CONFIGSOURCEPATHDEPRECATION']._serialized_start=4830
  _globals['_CONFIGSOURCEPATHDEPRECATION']._serialized_end=4902
  _globals['_CONFIGSOURCEPATHDEPRECATIONMSG']._serialized_start=4905
  _globals['_CONFIGSOURCEPATHDEPRECATIONMSG']._serialized_end=5035
  _globals['_CONFIGDATAPATHDEPRECATION']._serialized_start=5037
  _globals['_CONFIGDATAPATHDEPRECATION']._serialized_end=5107
  _globals['_CONFIGDATAPATHDEPRECATIONMSG']._serialized_start=5109
  _globals['_CONFIGDATAPATHDEPRECATIONMSG']._serialized_end=5235
  _globals['_METRICATTRIBUTESRENAMED']._serialized_start=5237
  _globals['_METRICATTRIBUTESRENAMED']._serialized_end=5283
  _globals['_METRICATTRIBUTESRENAMEDMSG']._serialized_start=5285
  _globals['_METRICATTRIBUTESRENAMEDMSG']._serialized_end=5407
  _globals['_EXPOSURENAMEDEPRECATION']._serialized_start=5409
  _globals['_EXPOSURENAMEDEPRECATION']._serialized_end=5452
  _globals['_EXPOSURENAMEDEPRECATIONMSG']._serialized_start=5454
  _globals['_EXPOSURENAMEDEPRECATIONMSG']._serialized_end=5576
  _globals['_INTERNALDEPRECATION']._serialized_start=5578
  _globals['_INTERNALDEPRECATION']._serialized_end=5672
  _globals['_INTERNALDEPRECATIONMSG']._serialized_start=5674
  _globals['_INTERNALDEPRECATIONMSG']._serialized_end=5788
  _globals['_ENVIRONMENTVARIABLERENAMED']._serialized_start=5790
  _globals['_ENVIRONMENTVARIABLERENAMED']._serialized_end=5854
  _globals['_ENVIRONMENTVARIABLERENAMEDMSG']._serialized_start=5857
  _globals['_ENVIRONMENTVARIABLERENAMEDMSG']._serialized_end=5985
  _globals['_CONFIGLOGPATHDEPRECATION']._serialized_start=5987
  _globals['_CONFIGLOGPATHDEPRECATION']._serialized_end=6038
  _globals['_CONFIGLOGPATHDEPRECATIONMSG']._serialized_start=6040
  _globals['_CONFIGLOGPATHDEPRECATIONMSG']._serialized_end=6164
  _globals['_CONFIGTARGETPATHDEPRECATION']._serialized_start=6166
  _globals['_CONFIGTARGETPATHDEPRECATION']._serialized_end=6220
  _globals['_CONFIGTARGETPATHDEPRECATIONMSG']._serialized_start=6223
  _globals['_CONFIGTARGETPATHDEPRECATIONMSG']._serialized_end=6353
  _globals['_TESTSCONFIGDEPRECATION']._serialized_start=6355
  _globals['_TESTSCONFIGDEPRECATION']._serialized_end=6422
  _globals['_TESTSCONFIGDEPRECATIONMSG']._serialized_start=6424
  _globals['_TESTSCONFIGDEPRECATIONMSG']._serialized_end=6544
  _globals['_PROJECTFLAGSMOVEDDEPRECATION']._serialized_start=6546
  _globals['_PROJECTFLAGSMOVEDDEPRECATION']._serialized_end=6576
  _globals['_PROJECTFLAGSMOVEDDEPRECATIONMSG']._serialized_start=6579
  _globals['_PROJECTFLAGSMOVEDDEPRECATIONMSG']._serialized_end=6711
  _globals['_SPACESINRESOURCENAMEDEPRECATION']._serialized_start=6713
  _globals['_SPACESINRESOURCENAMEDEPRECATION']._serialized_end=6780
  _globals['_SPACESINRESOURCENAMEDEPRECATIONMSG']._serialized_start=6783
  _globals['_SPACESINRESOURCENAMEDEPRECATIONMSG']._serialized_end=6921
  _globals['_RESOURCENAMESWITHSPACESDEPRECATION']._serialized_start=6923
  _globals['_RESOURCENAMESWITHSPACESDEPRECATION']._serialized_end=7028
  _globals['_RESOURCENAMESWITHSPACESDEPRECATIONMSG']._serialized_start=7031
  _globals['_RESOURCENAMESWITHSPACESDEPRECATIONMSG']._serialized_end=7175
  _globals['_PACKAGEMATERIALIZATIONOVERRIDEDEPRECATION']._serialized_start=7177
  _globals['_PACKAGEMATERIALIZATIONOVERRIDEDEPRECATION']._serialized_end=7272
  _globals['_PACKAGEMATERIALIZATIONOVERRIDEDEPRECATIONMSG']._serialized_start=7275
  _globals['_PACKAGEMATERIALIZATIONOVERRIDEDEPRECATIONMSG']._serialized_end=7433
  _globals['_SOURCEFRESHNESSPROJECTHOOKSNOTRUN']._serialized_start=7435
  _globals['_SOURCEFRESHNESSPROJECTHOOKSNOTRUN']._serialized_end=7470
  _globals['_SOURCEFRESHNESSPROJECTHOOKSNOTRUNMSG']._serialized_start=7473
  _globals['_SOURCEFRESHNESSPROJECTHOOKSNOTRUNMSG']._serialized_end=7615
  _globals['_DEPRECATEDMODEL']._serialized_start=7617
  _globals['_DEPRECATEDMODEL']._serialized_end=7703
  _globals['_DEPRECATEDMODELMSG']._serialized_start=7705
  _globals['_DEPRECATEDMODELMSG']._serialized_end=7811
  _globals['_INPUTFILEDIFFERROR']._serialized_start=7813
  _globals['_INPUTFILEDIFFERROR']._serialized_end=7868
  _globals['_INPUTFILEDIFFERRORMSG']._serialized_start=7870
  _globals['_INPUTFILEDIFFERRORMSG']._serialized_end=7982
  _globals['_INVALIDVALUEFORFIELD']._serialized_start=7984
  _globals['_INVALIDVALUEFORFIELD']._serialized_end=8047
  _globals['_INVALIDVALUEFORFIELDMSG']._serialized_start=8049
  _globals['_INVALIDVALUEFORFIELDMSG']._serialized_end=8165
  _globals['_VALIDATIONWARNING']._serialized_start=8167
  _globals['_VALIDATIONWARNING']._serialized_end=8248
  _globals['_VALIDATIONWARNINGMSG']._serialized_start=8250
  _globals['_VALIDATIONWARNINGMSG']._serialized_end=8360
  _globals['_PARSEPERFINFOPATH']._serialized_start=8362
  _globals['_PARSEPERFINFOPATH']._serialized_end=8395
  _globals['_PARSEPERFINFOPATHMSG']._serialized_start=8397
  _globals['_PARSEPERFINFOPATHMSG']._serialized_end=8507
  _globals['_PARTIALPARSINGERRORPROCESSINGFILE']._serialized_start=8509
  _globals['_PARTIALPARSINGERRORPROCESSINGFILE']._serialized_end=8558
  _globals['_PARTIALPARSINGERRORPROCESSINGFILEMSG']._serialized_start=8561
  _globals['_PARTIALPARSINGERRORPROCESSINGFILEMSG']._serialized_end=8703
  _globals['_PARTIALPARSINGERROR']._serialized_start=8706
  _globals['_PARTIALPARSINGERROR']._serialized_end=8840
  _globals['_PARTIALPARSINGERROR_EXCINFOENTRY']._serialized_start=8794
  _globals['_PARTIALPARSINGERROR_EXCINFOENTRY']._serialized_end=8840
  _globals['_PARTIALPARSINGERRORMSG']._serialized_start=8842
  _globals['_PARTIALPARSINGERRORMSG']._serialized_end=8956
  _globals['_PARTIALPARSINGSKIPPARSING']._serialized_start=8958
  _globals['_PARTIALPARSINGSKIPPARSING']._serialized_end=8985
  _globals['_PARTIALPARSINGSKIPPARSINGMSG']._serialized_start=8987
  _globals['_PARTIALPARSINGSKIPPARSINGMSG']._serialized_end=9113
  _globals['_UNABLETOPARTIALPARSE']._serialized_start=9115
  _globals['_UNABLETOPARTIALPARSE']._serialized_end=9153
  _globals['_UNABLETOPARTIALPARSEMSG']._serialized_start=9155
  _globals['_UNABLETOPARTIALPARSEMSG']._serialized_end=9271
  _globals['_STATECHECKVARSHASH']._serialized_start=9273
  _globals['_STATECHECKVARSHASH']._serialized_end=9375
  _globals['_STATECHECKVARSHASHMSG']._serialized_start=9377
  _globals['_STATECHECKVARSHASHMSG']._serialized_end=9489
  _globals['_PARTIALPARSINGNOTENABLED']._serialized_start=9491
  _globals['_PARTIALPARSINGNOTENABLED']._serialized_end=9517
  _globals['_PARTIALPARSINGNOTENABLEDMSG']._serialized_start=9519
  _globals['_PARTIALPARSINGNOTENABLEDMSG']._serialized_end=9643
  _globals['_PARSEDFILELOADFAILED']._serialized_start=9645
  _globals['_PARSEDFILELOADFAILED']._serialized_end=9712
  _globals['_PARSEDFILELOADFAILEDMSG']._serialized_start=9714
  _globals['_PARSEDFILELOADFAILEDMSG']._serialized_end=9830
  _globals['_PARTIALPARSINGENABLED']._serialized_start=9832
  _globals['_PARTIALPARSINGENABLED']._serialized_end=9904
  _globals['_PARTIALPARSINGENABLEDMSG']._serialized_start=9906
  _globals['_PARTIALPARSINGENABLEDMSG']._serialized_end=10024
  _globals['_PARTIALPARSINGFILE']._serialized_start=10026
  _globals['_PARTIALPARSINGFILE']._serialized_end=10082
  _globals['_PARTIALPARSINGFILEMSG']._serialized_start=10084
  _globals['_PARTIALPARSINGFILEMSG']._serialized_end=10196
  _globals['_INVALIDDISABLEDTARGETINTESTNODE']._serialized_start=10199
  _globals['_INVALIDDISABLEDTARGETINTESTNODE']._serialized_end=10374
  _globals['_INVALIDDISABLEDTARGETINTESTNODEMSG']._serialized_start=10377
  _globals['_INVALIDDISABLEDTARGETINTESTNODEMSG']._serialized_end=10515
  _globals['_UNUSEDRESOURCECONFIGPATH']._serialized_start=10517
  _globals['_UNUSEDRESOURCECONFIGPATH']._serialized_end=10572
  _globals['_UNUSEDRESOURCECONFIGPATHMSG']._serialized_start=10574
  _globals['_UNUSEDRESOURCECONFIGPATHMSG']._serialized_end=10698
  _globals['_SEEDINCREASED']._serialized_start=10700
  _globals['_SEEDINCREASED']._serialized_end=10751
  _globals['_SEEDINCREASEDMSG']._serialized_start=10753
  _globals['_SEEDINCREASEDMSG']._serialized_end=10855
  _globals['_SEEDEXCEEDSLIMITSAMEPATH']._serialized_start=10857
  _globals['_SEEDEXCEEDSLIMITSAMEPATH']._serialized_end=10919
  _globals['_SEEDEXCEEDSLIMITSAMEPATHMSG']._serialized_start=10921
  _globals['_SEEDEXCEEDSLIMITSAMEPATHMSG']._serialized_end=11045
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGED']._serialized_start=11047
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGED']._serialized_end=11115
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGEDMSG']._serialized_start=11118
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGEDMSG']._serialized_end=11254
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGED']._serialized_start=11256
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGED']._serialized_end=11348
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGEDMSG']._serialized_start=11351
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGEDMSG']._serialized_end=11489
  _globals['_UNUSEDTABLES']._serialized_start=11491
  _globals['_UNUSEDTABLES']._serialized_end=11528
  _globals['_UNUSEDTABLESMSG']._serialized_start=11530
  _globals['_UNUSEDTABLESMSG']._serialized_end=11630
  _globals['_WRONGRESOURCESCHEMAFILE']._serialized_start=11633
  _globals['_WRONGRESOURCESCHEMAFILE']._serialized_end=11768
  _globals['_WRONGRESOURCESCHEMAFILEMSG']._serialized_start=11770
  _globals['_WRONGRESOURCESCHEMAFILEMSG']._serialized_end=11892
  _globals['_NONODEFORYAMLKEY']._serialized_start=11894
  _globals['_NONODEFORYAMLKEY']._serialized_end=11969
  _globals['_NONODEFORYAMLKEYMSG']._serialized_start=11971
  _globals['_NONODEFORYAMLKEYMSG']._serialized_end=12079
  _globals['_MACRONOTFOUNDFORPATCH']._serialized_start=12081
  _globals['_MACRONOTFOUNDFORPATCH']._serialized_end=12124
  _globals['_MACRONOTFOUNDFORPATCHMSG']._serialized_start=12126
  _globals['_MACRONOTFOUNDFORPATCHMSG']._serialized_end=12244
  _globals['_NODENOTFOUNDORDISABLED']._serialized_start=12247
  _globals['_NODENOTFOUNDORDISABLED']._serialized_end=12431
  _globals['_NODENOTFOUNDORDISABLEDMSG']._serialized_start=12433
  _globals['_NODENOTFOUNDORDISABLEDMSG']._serialized_end=12553
  _globals['_JINJALOGWARNING']._serialized_start=12555
  _globals['_JINJALOGWARNING']._serialized_end=12627
  _globals['_JINJALOGWARNINGMSG']._serialized_start=12629
  _globals['_JINJALOGWARNINGMSG']._serialized_end=12735
  _globals['_JINJALOGINFO']._serialized_start=12737
  _globals['_JINJALOGINFO']._serialized_end=12806
  _globals['_JINJALOGINFOMSG']._serialized_start=12808
  _globals['_JINJALOGINFOMSG']._serialized_end=12908
  _globals['_JINJALOGDEBUG']._serialized_start=12910
  _globals['_JINJALOGDEBUG']._serialized_end=12980
  _globals['_JINJALOGDEBUGMSG']._serialized_start=12982
  _globals['_JINJALOGDEBUGMSG']._serialized_end=13084
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLE']._serialized_start=13087
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLE']._serialized_end=13261
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLEMSG']._serialized_start=13264
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLEMSG']._serialized_end=13400
  _globals['_UPCOMINGREFERENCEDEPRECATION']._serialized_start=13403
  _globals['_UPCOMINGREFERENCEDEPRECATION']._serialized_end=13601
  _globals['_UPCOMINGREFERENCEDEPRECATIONMSG']._serialized_start=13604
  _globals['_UPCOMINGREFERENCEDEPRECATIONMSG']._serialized_end=13736
  _globals['_DEPRECATEDREFERENCE']._serialized_start=13739
  _globals['_DEPRECATEDREFERENCE']._serialized_end=13928
  _globals['_DEPRECATEDREFERENCEMSG']._serialized_start=13930
  _globals['_DEPRECATEDREFERENCEMSG']._serialized_end=14044
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATION']._serialized_start=14046
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATION']._serialized_end=14106
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATIONMSG']._serialized_start=14109
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATIONMSG']._serialized_end=14257
  _globals['_PARSEINLINENODEERROR']._serialized_start=14259
  _globals['_PARSEINLINENODEERROR']._serialized_end=14336
  _globals['_PARSEINLINENODEERRORMSG']._serialized_start=14338
  _globals['_PARSEINLINENODEERRORMSG']._serialized_end=14454
  _globals['_SEMANTICVALIDATIONFAILURE']._serialized_start=14456
  _globals['_SEMANTICVALIDATIONFAILURE']._serialized_end=14496
  _globals['_SEMANTICVALIDATIONFAILUREMSG']._serialized_start=14498
  _globals['_SEMANTICVALIDATIONFAILUREMSG']._serialized_end=14624
  _globals['_UNVERSIONEDBREAKINGCHANGE']._serialized_start=14627
  _globals['_UNVERSIONEDBREAKINGCHANGE']._serialized_end=15021
  _globals['_UNVERSIONEDBREAKINGCHANGEMSG']._serialized_start=15023
  _globals['_UNVERSIONEDBREAKINGCHANGEMSG']._serialized_end=15149
  _globals['_WARNSTATETARGETEQUAL']._serialized_start=15151
  _globals['_WARNSTATETARGETEQUAL']._serialized_end=15193
  _globals['_WARNSTATETARGETEQUALMSG']._serialized_start=15195
  _globals['_WARNSTATETARGETEQUALMSG']._serialized_end=15311
  _globals['_FRESHNESSCONFIGPROBLEM']._serialized_start=15313
  _globals['_FRESHNESSCONFIGPROBLEM']._serialized_end=15350
  _globals['_FRESHNESSCONFIGPROBLEMMSG']._serialized_start=15352
  _globals['_FRESHNESSCONFIGPROBLEMMSG']._serialized_end=15472
  _globals['_GITSPARSECHECKOUTSUBDIRECTORY']._serialized_start=15474
  _globals['_GITSPARSECHECKOUTSUBDIRECTORY']._serialized_end=15521
  _globals['_GITSPARSECHECKOUTSUBDIRECTORYMSG']._serialized_start=15524
  _globals['_GITSPARSECHECKOUTSUBDIRECTORYMSG']._serialized_end=15658
  _globals['_GITPROGRESSCHECKOUTREVISION']._serialized_start=15660
  _globals['_GITPROGRESSCHECKOUTREVISION']._serialized_end=15707
  _globals['_GITPROGRESSCHECKOUTREVISIONMSG']._serialized_start=15710
  _globals['_GITPROGRESSCHECKOUTREVISIONMSG']._serialized_end=15840
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCY']._serialized_start=15842
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCY']._serialized_end=15894
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCYMSG']._serialized_start=15897
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCYMSG']._serialized_end=16047
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCY']._serialized_start=16049
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCY']._serialized_end=16095
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCYMSG']._serialized_start=16098
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCYMSG']._serialized_end=16236
  _globals['_GITNOTHINGTODO']._serialized_start=16238
  _globals['_GITNOTHINGTODO']._serialized_end=16267
  _globals['_GITNOTHINGTODOMSG']._serialized_start=16269
  _globals['_GITNOTHINGTODOMSG']._serialized_end=16373
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGE']._serialized_start=16375
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGE']._serialized_end=16444
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGEMSG']._serialized_start=16447
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGEMSG']._serialized_end=16585
  _globals['_GITPROGRESSCHECKEDOUTAT']._serialized_start=16587
  _globals['_GITPROGRESSCHECKEDOUTAT']._serialized_end=16629
  _globals['_GITPROGRESSCHECKEDOUTATMSG']._serialized_start=16631
  _globals['_GITPROGRESSCHECKEDOUTATMSG']._serialized_end=16753
  _globals['_REGISTRYPROGRESSGETREQUEST']._serialized_start=16755
  _globals['_REGISTRYPROGRESSGETREQUEST']._serialized_end=16796
  _globals['_REGISTRYPROGRESSGETREQUESTMSG']._serialized_start=16799
  _globals['_REGISTRYPROGRESSGETREQUESTMSG']._serialized_end=16927
  _globals['_REGISTRYPROGRESSGETRESPONSE']._serialized_start=16929
  _globals['_REGISTRYPROGRESSGETRESPONSE']._serialized_end=16990
  _globals['_REGISTRYPROGRESSGETRESPONSEMSG']._serialized_start=16993
  _globals['_REGISTRYPROGRESSGETRESPONSEMSG']._serialized_end=17123
  _globals['_SELECTORREPORTINVALIDSELECTOR']._serialized_start=17125
  _globals['_SELECTORREPORTINVALIDSELECTOR']._serialized_end=17220
  _globals['_SELECTORREPORTINVALIDSELECTORMSG']._serialized_start=17223
  _globals['_SELECTORREPORTINVALIDSELECTORMSG']._serialized_end=17357
  _globals['_DEPSNOPACKAGESFOUND']._serialized_start=17359
  _globals['_DEPSNOPACKAGESFOUND']._serialized_end=17380
  _globals['_DEPSNOPACKAGESFOUNDMSG']._serialized_start=17382
  _globals['_DEPSNOPACKAGESFOUNDMSG']._serialized_end=17496
  _globals['_DEPSSTARTPACKAGEINSTALL']._serialized_start=17498
  _globals['_DEPSSTARTPACKAGEINSTALL']._serialized_end=17545
  _globals['_DEPSSTARTPACKAGEINSTALLMSG']._serialized_start=17547
  _globals['_DEPSSTARTPACKAGEINSTALLMSG']._serialized_end=17669
  _globals['_DEPSINSTALLINFO']._serialized_start=17671
  _globals['_DEPSINSTALLINFO']._serialized_end=17710
  _globals['_DEPSINSTALLINFOMSG']._serialized_start=17712
  _globals['_DEPSINSTALLINFOMSG']._serialized_end=17818
  _globals['_DEPSUPDATEAVAILABLE']._serialized_start=17820
  _globals['_DEPSUPDATEAVAILABLE']._serialized_end=17865
  _globals['_DEPSUPDATEAVAILABLEMSG']._serialized_start=17867
  _globals['_DEPSUPDATEAVAILABLEMSG']._serialized_end=17981
  _globals['_DEPSUPTODATE']._serialized_start=17983
  _globals['_DEPSUPTODATE']._serialized_end=17997
  _globals['_DEPSUPTODATEMSG']._serialized_start=17999
  _globals['_DEPSUPTODATEMSG']._serialized_end=18099
  _globals['_DEPSLISTSUBDIRECTORY']._serialized_start=18101
  _globals['_DEPSLISTSUBDIRECTORY']._serialized_end=18145
  _globals['_DEPSLISTSUBDIRECTORYMSG']._serialized_start=18147
  _globals['_DEPSLISTSUBDIRECTORYMSG']._serialized_end=18263
  _globals['_DEPSNOTIFYUPDATESAVAILABLE']._serialized_start=18265
  _globals['_DEPSNOTIFYUPDATESAVAILABLE']._serialized_end=18311
  _globals['_DEPSNOTIFYUPDATESAVAILABLEMSG']._serialized_start=18314
  _globals['_DEPSNOTIFYUPDATESAVAILABLEMSG']._serialized_end=18442
  _globals['_REGISTRYINDEXPROGRESSGETREQUEST']._serialized_start=18444
  _globals['_REGISTRYINDEXPROGRESSGETREQUEST']._serialized_end=18490
  _globals['_REGISTRYINDEXPROGRESSGETREQUESTMSG']._serialized_start=18493
  _globals['_REGISTRYINDEXPROGRESSGETREQUESTMSG']._serialized_end=18631
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSE']._serialized_start=18633
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSE']._serialized_end=18699
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSEMSG']._serialized_start=18702
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSEMSG']._serialized_end=18842
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPE']._serialized_start=18844
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPE']._serialized_end=18894
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPEMSG']._serialized_start=18897
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPEMSG']._serialized_end=19033
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYS']._serialized_start=19035
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYS']._serialized_end=19085
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYSMSG']._serialized_start=19088
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYSMSG']._serialized_end=19224
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYS']._serialized_start=19226
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYS']._serialized_end=19279
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYSMSG']._serialized_start=19282
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYSMSG']._serialized_end=19424
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYS']._serialized_start=19426
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYS']._serialized_end=19477
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYSMSG']._serialized_start=19480
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYSMSG']._serialized_end=19618
  _globals['_DEPSSETDOWNLOADDIRECTORY']._serialized_start=19620
  _globals['_DEPSSETDOWNLOADDIRECTORY']._serialized_end=19660
  _globals['_DEPSSETDOWNLOADDIRECTORYMSG']._serialized_start=19662
  _globals['_DEPSSETDOWNLOADDIRECTORYMSG']._serialized_end=19786
  _globals['_DEPSUNPINNED']._serialized_start=19788
  _globals['_DEPSUNPINNED']._serialized_end=19833
  _globals['_DEPSUNPINNEDMSG']._serialized_start=19835
  _globals['_DEPSUNPINNEDMSG']._serialized_end=19935
  _globals['_NONODESFORSELECTIONCRITERIA']._serialized_start=19937
  _globals['_NONODESFORSELECTIONCRITERIA']._serialized_end=19984
  _globals['_NONODESFORSELECTIONCRITERIAMSG']._serialized_start=19987
  _globals['_NONODESFORSELECTIONCRITERIAMSG']._serialized_end=20117
  _globals['_DEPSLOCKUPDATING']._serialized_start=20119
  _globals['_DEPSLOCKUPDATING']._serialized_end=20160
  _globals['_DEPSLOCKUPDATINGMSG']._serialized_start=20162
  _globals['_DEPSLOCKUPDATINGMSG']._serialized_end=20270
  _globals['_DEPSADDPACKAGE']._serialized_start=20272
  _globals['_DEPSADDPACKAGE']._serialized_end=20354
  _globals['_DEPSADDPACKAGEMSG']._serialized_start=20356
  _globals['_DEPSADDPACKAGEMSG']._serialized_end=20460
  _globals['_DEPSFOUNDDUPLICATEPACKAGE']._serialized_start=20463
  _globals['_DEPSFOUNDDUPLICATEPACKAGE']._serialized_end=20630
  _globals['_DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY']._serialized_start=20577
  _globals['_DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY']._serialized_end=20630
  _globals['_DEPSFOUNDDUPLICATEPACKAGEMSG']._serialized_start=20632
  _globals['_DEPSFOUNDDUPLICATEPACKAGEMSG']._serialized_end=20758
  _globals['_DEPSVERSIONMISSING']._serialized_start=20760
  _globals['_DEPSVERSIONMISSING']._serialized_end=20796
  _globals['_DEPSVERSIONMISSINGMSG']._serialized_start=20798
  _globals['_DEPSVERSIONMISSINGMSG']._serialized_end=20910
  _globals['_DEPSSCRUBBEDPACKAGENAME']._serialized_start=20912
  _globals['_DEPSSCRUBBEDPACKAGENAME']._serialized_end=20959
  _globals['_DEPSSCRUBBEDPACKAGENAMEMSG']._serialized_start=20961
  _globals['_DEPSSCRUBBEDPACKAGENAMEMSG']._serialized_end=21083
  _globals['_RUNNINGOPERATIONCAUGHTERROR']._serialized_start=21085
  _globals['_RUNNINGOPERATIONCAUGHTERROR']._serialized_end=21127
  _globals['_RUNNINGOPERATIONCAUGHTERRORMSG']._serialized_start=21130
  _globals['_RUNNINGOPERATIONCAUGHTERRORMSG']._serialized_end=21260
  _globals['_COMPILECOMPLETE']._serialized_start=21262
  _globals['_COMPILECOMPLETE']._serialized_end=21279
  _globals['_COMPILECOMPLETEMSG']._serialized_start=21281
  _globals['_COMPILECOMPLETEMSG']._serialized_end=21387
  _globals['_FRESHNESSCHECKCOMPLETE']._serialized_start=21389
  _globals['_FRESHNESSCHECKCOMPLETE']._serialized_end=21413
  _globals['_FRESHNESSCHECKCOMPLETEMSG']._serialized_start=21415
  _globals['_FRESHNESSCHECKCOMPLETEMSG']._serialized_end=21535
  _globals['_SEEDHEADER']._serialized_start=21537
  _globals['_SEEDHEADER']._serialized_end=21565
  _globals['_SEEDHEADERMSG']._serialized_start=21567
  _globals['_SEEDHEADERMSG']._serialized_end=21663
  _globals['_SQLRUNNEREXCEPTION']._serialized_start=21665
  _globals['_SQLRUNNEREXCEPTION']._serialized_end=21758
  _globals['_SQLRUNNEREXCEPTIONMSG']._serialized_start=21760
  _globals['_SQLRUNNEREXCEPTIONMSG']._serialized_end=21872
  _globals['_LOGTESTRESULT']._serialized_start=21875
  _globals['_LOGTESTRESULT']._serialized_end=22043
  _globals['_LOGTESTRESULTMSG']._serialized_start=22045
  _globals['_LOGTESTRESULTMSG']._serialized_end=22147
  _globals['_LOGSTARTLINE']._serialized_start=22149
  _globals['_LOGSTARTLINE']._serialized_end=22256
  _globals['_LOGSTARTLINEMSG']._serialized_start=22258
  _globals['_LOGSTARTLINEMSG']._serialized_end=22358
  _globals['_LOGMODELRESULT']._serialized_start=22361
  _globals['_LOGMODELRESULT']._serialized_end=22510
  _globals['_LOGMODELRESULTMSG']._serialized_start=22512
  _globals['_LOGMODELRESULTMSG']._serialized_end=22616
  _globals['_LOGSNAPSHOTRESULT']._serialized_start=22619
  _globals['_LOGSNAPSHOTRESULT']._serialized_end=22893
  _globals['_LOGSNAPSHOTRESULT_CFGENTRY']._serialized_start=22851
  _globals['_LOGSNAPSHOTRESULT_CFGENTRY']._serialized_end=22893
  _globals['_LOGSNAPSHOTRESULTMSG']._serialized_start=22895
  _globals['_LOGSNAPSHOTRESULTMSG']._serialized_end=23005
  _globals['_LOGSEEDRESULT']._serialized_start=23008
  _globals['_LOGSEEDRESULT']._serialized_end=23193
  _globals['_LOGSEEDRESULTMSG']._serialized_start=23195
  _globals['_LOGSEEDRESULTMSG']._serialized_end=23297
  _globals['_LOGFRESHNESSRESULT']._serialized_start=23300
  _globals['_LOGFRESHNESSRESULT']._serialized_end=23473
  _globals['_LOGFRESHNESSRESULTMSG']._serialized_start=23475
  _globals['_LOGFRESHNESSRESULTMSG']._serialized_end=23587
  _globals['_LOGNODENOOPRESULT']._serialized_start=23590
  _globals['_LOGNODENOOPRESULT']._serialized_end=23742
  _globals['_LOGNODENOOPRESULTMSG']._serialized_start=23744
  _globals['_LOGNODENOOPRESULTMSG']._serialized_end=23854
  _globals['_LOGCANCELLINE']._serialized_start=23856
  _globals['_LOGCANCELLINE']._serialized_end=23890
  _globals['_LOGCANCELLINEMSG']._serialized_start=23892
  _globals['_LOGCANCELLINEMSG']._serialized_end=23994
  _globals['_DEFAULTSELECTOR']._serialized_start=23996
  _globals['_DEFAULTSELECTOR']._serialized_end=24027
  _globals['_DEFAULTSELECTORMSG']._serialized_start=24029
  _globals['_DEFAULTSELECTORMSG']._serialized_end=24135
  _globals['_NODESTART']._serialized_start=24137
  _globals['_NODESTART']._serialized_end=24190
  _globals['_NODESTARTMSG']._serialized_start=24192
  _globals['_NODESTARTMSG']._serialized_end=24286
  _globals['_NODEFINISHED']._serialized_start=24288
  _globals['_NODEFINISHED']._serialized_end=24391
  _globals['_NODEFINISHEDMSG']._serialized_start=24393
  _globals['_NODEFINISHEDMSG']._serialized_end=24493
  _globals['_QUERYCANCELATIONUNSUPPORTED']._serialized_start=24495
  _globals['_QUERYCANCELATIONUNSUPPORTED']._serialized_end=24538
  _globals['_QUERYCANCELATIONUNSUPPORTEDMSG']._serialized_start=24541
  _globals['_QUERYCANCELATIONUNSUPPORTEDMSG']._serialized_end=24671
  _globals['_CONCURRENCYLINE']._serialized_start=24673
  _globals['_CONCURRENCYLINE']._serialized_end=24752
  _globals['_CONCURRENCYLINEMSG']._serialized_start=24754
  _globals['_CONCURRENCYLINEMSG']._serialized_end=24860
  _globals['_WRITINGINJECTEDSQLFORNODE']._serialized_start=24862
  _globals['_WRITINGINJECTEDSQLFORNODE']._serialized_end=24931
  _globals['_WRITINGINJECTEDSQLFORNODEMSG']._serialized_start=24933
  _globals['_WRITINGINJECTEDSQLFORNODEMSG']._serialized_end=25059
  _globals['_NODECOMPILING']._serialized_start=25061
  _globals['_NODECOMPILING']._serialized_end=25118
  _globals['_NODECOMPILINGMSG']._serialized_start=25120
  _globals['_NODECOMPILINGMSG']._serialized_end=25222
  _globals['_NODEEXECUTING']._serialized_start=25224
  _globals['_NODEEXECUTING']._serialized_end=25281
  _globals['_NODEEXECUTINGMSG']._serialized_start=25283
  _globals['_NODEEXECUTINGMSG']._serialized_end=25385
  _globals['_LOGHOOKSTARTLINE']._serialized_start=25387
  _globals['_LOGHOOKSTARTLINE']._serialized_end=25496
  _globals['_LOGHOOKSTARTLINEMSG']._serialized_start=25498
  _globals['_LOGHOOKSTARTLINEMSG']._serialized_end=25606
  _globals['_LOGHOOKENDLINE']._serialized_start=25609
  _globals['_LOGHOOKENDLINE']._serialized_end=25756
  _globals['_LOGHOOKENDLINEMSG']._serialized_start=25758
  _globals['_LOGHOOKENDLINEMSG']._serialized_end=25862
  _globals['_SKIPPINGDETAILS']._serialized_start=25865
  _globals['_SKIPPINGDETAILS']._serialized_end=26012
  _globals['_SKIPPINGDETAILSMSG']._serialized_start=26014
  _globals['_SKIPPINGDETAILSMSG']._serialized_end=26120
  _globals['_NOTHINGTODO']._serialized_start=26122
  _globals['_NOTHINGTODO']._serialized_end=26135
  _globals['_NOTHINGTODOMSG']._serialized_start=26137
  _globals['_NOTHINGTODOMSG']._serialized_end=26235
  _globals['_RUNNINGOPERATIONUNCAUGHTERROR']._serialized_start=26237
  _globals['_RUNNINGOPERATIONUNCAUGHTERROR']._serialized_end=26281
  _globals['_RUNNINGOPERATIONUNCAUGHTERRORMSG']._serialized_start=26284
  _globals['_RUNNINGOPERATIONUNCAUGHTERRORMSG']._serialized_end=26418
  _globals['_ENDRUNRESULT']._serialized_start=26421
  _globals['_ENDRUNRESULT']._serialized_end=26568
  _globals['_ENDRUNRESULTMSG']._serialized_start=26570
  _globals['_ENDRUNRESULTMSG']._serialized_end=26670
  _globals['_NONODESSELECTED']._serialized_start=26672
  _globals['_NONODESSELECTED']._serialized_end=26689
  _globals['_NONODESSELECTEDMSG']._serialized_start=26691
  _globals['_NONODESSELECTEDMSG']._serialized_end=26797
  _globals['_COMMANDCOMPLETED']._serialized_start=26799
  _globals['_COMMANDCOMPLETED']._serialized_end=26918
  _globals['_COMMANDCOMPLETEDMSG']._serialized_start=26920
  _globals['_COMMANDCOMPLETEDMSG']._serialized_end=27028
  _globals['_SHOWNODE']._serialized_start=27030
  _globals['_SHOWNODE']._serialized_end=27137
  _globals['_SHOWNODEMSG']._serialized_start=27139
  _globals['_SHOWNODEMSG']._serialized_end=27231
  _globals['_COMPILEDNODE']._serialized_start=27233
  _globals['_COMPILEDNODE']._serialized_end=27345
  _globals['_COMPILEDNODEMSG']._serialized_start=27347
  _globals['_COMPILEDNODEMSG']._serialized_end=27447
  _globals['_CATCHABLEEXCEPTIONONRUN']._serialized_start=27449
  _globals['_CATCHABLEEXCEPTIONONRUN']._serialized_end=27547
  _globals['_CATCHABLEEXCEPTIONONRUNMSG']._serialized_start=27549
  _globals['_CATCHABLEEXCEPTIONONRUNMSG']._serialized_end=27671
  _globals['_INTERNALERRORONRUN']._serialized_start=27673
  _globals['_INTERNALERRORONRUN']._serialized_end=27768
  _globals['_INTERNALERRORONRUNMSG']._serialized_start=27770
  _globals['_INTERNALERRORONRUNMSG']._serialized_end=27882
  _globals['_GENERICEXCEPTIONONRUN']._serialized_start=27884
  _globals['_GENERICEXCEPTIONONRUN']._serialized_end=28001
  _globals['_GENERICEXCEPTIONONRUNMSG']._serialized_start=28003
  _globals['_GENERICEXCEPTIONONRUNMSG']._serialized_end=28121
  _globals['_NODECONNECTIONRELEASEERROR']._serialized_start=28123
  _globals['_NODECONNECTIONRELEASEERROR']._serialized_end=28201
  _globals['_NODECONNECTIONRELEASEERRORMSG']._serialized_start=28204
  _globals['_NODECONNECTIONRELEASEERRORMSG']._serialized_end=28332
  _globals['_FOUNDSTATS']._serialized_start=28334
  _globals['_FOUNDSTATS']._serialized_end=28365
  _globals['_FOUNDSTATSMSG']._serialized_start=28367
  _globals['_FOUNDSTATSMSG']._serialized_end=28463
  _globals['_MAINKEYBOARDINTERRUPT']._serialized_start=28465
  _globals['_MAINKEYBOARDINTERRUPT']._serialized_end=28488
  _globals['_MAINKEYBOARDINTERRUPTMSG']._serialized_start=28490
  _globals['_MAINKEYBOARDINTERRUPTMSG']._serialized_end=28608
  _globals['_MAINENCOUNTEREDERROR']._serialized_start=28610
  _globals['_MAINENCOUNTEREDERROR']._serialized_end=28645
  _globals['_MAINENCOUNTEREDERRORMSG']._serialized_start=28647
  _globals['_MAINENCOUNTEREDERRORMSG']._serialized_end=28763
  _globals['_MAINSTACKTRACE']._serialized_start=28765
  _globals['_MAINSTACKTRACE']._serialized_end=28802
  _globals['_MAINSTACKTRACEMSG']._serialized_start=28804
  _globals['_MAINSTACKTRACEMSG']._serialized_end=28908
  _globals['_TIMINGINFOCOLLECTED']._serialized_start=28910
  _globals['_TIMINGINFOCOLLECTED']._serialized_end=29022
  _globals['_TIMINGINFOCOLLECTEDMSG']._serialized_start=29024
  _globals['_TIMINGINFOCOLLECTEDMSG']._serialized_end=29138
  _globals['_LOGDEBUGSTACKTRACE']._serialized_start=29140
  _globals['_LOGDEBUGSTACKTRACE']._serialized_end=29178
  _globals['_LOGDEBUGSTACKTRACEMSG']._serialized_start=29180
  _globals['_LOGDEBUGSTACKTRACEMSG']._serialized_end=29292
  _globals['_CHECKCLEANPATH']._serialized_start=29294
  _globals['_CHECKCLEANPATH']._serialized_end=29324
  _globals['_CHECKCLEANPATHMSG']._serialized_start=29326
  _globals['_CHECKCLEANPATHMSG']._serialized_end=29430
  _globals['_CONFIRMCLEANPATH']._serialized_start=29432
  _globals['_CONFIRMCLEANPATH']._serialized_end=29464
  _globals['_CONFIRMCLEANPATHMSG']._serialized_start=29466
  _globals['_CONFIRMCLEANPATHMSG']._serialized_end=29574
  _globals['_PROTECTEDCLEANPATH']._serialized_start=29576
  _globals['_PROTECTEDCLEANPATH']._serialized_end=29610
  _globals['_PROTECTEDCLEANPATHMSG']._serialized_start=29612
  _globals['_PROTECTEDCLEANPATHMSG']._serialized_end=29724
  _globals['_FINISHEDCLEANPATHS']._serialized_start=29726
  _globals['_FINISHEDCLEANPATHS']._serialized_end=29746
  _globals['_FINISHEDCLEANPATHSMSG']._serialized_start=29748
  _globals['_FINISHEDCLEANPATHSMSG']._serialized_end=29860
  _globals['_OPENCOMMAND']._serialized_start=29862
  _globals['_OPENCOMMAND']._serialized_end=29915
  _globals['_OPENCOMMANDMSG']._serialized_start=29917
  _globals['_OPENCOMMANDMSG']._serialized_end=30015
  _globals['_SERVINGDOCSPORT']._serialized_start=30017
  _globals['_SERVINGDOCSPORT']._serialized_end=30065
  _globals['_SERVINGDOCSPORTMSG']._serialized_start=30067
  _globals['_SERVINGDOCSPORTMSG']._serialized_end=30173
  _globals['_SERVINGDOCSACCESSINFO']._serialized_start=30175
  _globals['_SERVINGDOCSACCESSINFO']._serialized_end=30212
  _globals['_SERVINGDOCSACCESSINFOMSG']._serialized_start=30214
  _globals['_SERVINGDOCSACCESSINFOMSG']._serialized_end=30332
  _globals['_SERVINGDOCSEXITINFO']._serialized_start=30334
  _globals['_SERVINGDOCSEXITINFO']._serialized_end=30355
  _globals['_SERVINGDOCSEXITINFOMSG']._serialized_start=30357
  _globals['_SERVINGDOCSEXITINFOMSG']._serialized_end=30471
  _globals['_RUNRESULTWARNING']._serialized_start=30473
  _globals['_RUNRESULTWARNING']._serialized_end=30589
  _globals['_RUNRESULTWARNINGMSG']._serialized_start=30591
  _globals['_RUNRESULTWARNINGMSG']._serialized_end=30699
  _globals['_RUNRESULTFAILURE']._serialized_start=30701
  _globals['_RUNRESULTFAILURE']._serialized_end=30817
  _globals['_RUNRESULTFAILUREMSG']._serialized_start=30819
  _globals['_RUNRESULTFAILUREMSG']._serialized_end=30927
  _globals['_STATSLINE']._serialized_start=30929
  _globals['_STATSLINE']._serialized_end=31036
  _globals['_STATSLINE_STATSENTRY']._serialized_start=30992
  _globals['_STATSLINE_STATSENTRY']._serialized_end=31036
  _globals['_STATSLINEMSG']._serialized_start=31038
  _globals['_STATSLINEMSG']._serialized_end=31132
  _globals['_RUNRESULTERROR']._serialized_start=31134
  _globals['_RUNRESULTERROR']._serialized_end=31205
  _globals['_RUNRESULTERRORMSG']._serialized_start=31207
  _globals['_RUNRESULTERRORMSG']._serialized_end=31311
  _globals['_RUNRESULTERRORNOMESSAGE']._serialized_start=31313
  _globals['_RUNRESULTERRORNOMESSAGE']._serialized_end=31396
  _globals['_RUNRESULTERRORNOMESSAGEMSG']._serialized_start=31398
  _globals['_RUNRESULTERRORNOMESSAGEMSG']._serialized_end=31520
  _globals['_SQLCOMPILEDPATH']._serialized_start=31522
  _globals['_SQLCOMPILEDPATH']._serialized_end=31595
  _globals['_SQLCOMPILEDPATHMSG']._serialized_start=31597
  _globals['_SQLCOMPILEDPATHMSG']._serialized_end=31703
  _globals['_CHECKNODETESTFAILURE']._serialized_start=31705
  _globals['_CHECKNODETESTFAILURE']._serialized_end=31792
  _globals['_CHECKNODETESTFAILUREMSG']._serialized_start=31794
  _globals['_CHECKNODETESTFAILUREMSG']._serialized_end=31910
  _globals['_ENDOFRUNSUMMARY']._serialized_start=31912
  _globals['_ENDOFRUNSUMMARY']._serialized_end=31999
  _globals['_ENDOFRUNSUMMARYMSG']._serialized_start=32001
  _globals['_ENDOFRUNSUMMARYMSG']._serialized_end=32107
  _globals['_LOGSKIPBECAUSEERROR']._serialized_start=32109
  _globals['_LOGSKIPBECAUSEERROR']._serialized_end=32194
  _globals['_LOGSKIPBECAUSEERRORMSG']._serialized_start=32196
  _globals['_LOGSKIPBECAUSEERRORMSG']._serialized_end=32310
  _globals['_ENSUREGITINSTALLED']._serialized_start=32312
  _globals['_ENSUREGITINSTALLED']._serialized_end=32332
  _globals['_ENSUREGITINSTALLEDMSG']._serialized_start=32334
  _globals['_ENSUREGITINSTALLEDMSG']._serialized_end=32446
  _globals['_DEPSCREATINGLOCALSYMLINK']._serialized_start=32448
  _globals['_DEPSCREATINGLOCALSYMLINK']._serialized_end=32474
  _globals['_DEPSCREATINGLOCALSYMLINKMSG']._serialized_start=32476
  _globals['_DEPSCREATINGLOCALSYMLINKMSG']._serialized_end=32600
  _globals['_DEPSSYMLINKNOTAVAILABLE']._serialized_start=32602
  _globals['_DEPSSYMLINKNOTAVAILABLE']._serialized_end=32627
  _globals['_DEPSSYMLINKNOTAVAILABLEMSG']._serialized_start=32629
  _globals['_DEPSSYMLINKNOTAVAILABLEMSG']._serialized_end=32751
  _globals['_DISABLETRACKING']._serialized_start=32753
  _globals['_DISABLETRACKING']._serialized_end=32770
  _globals['_DISABLETRACKINGMSG']._serialized_start=32772
  _globals['_DISABLETRACKINGMSG']._serialized_end=32878
  _globals['_SENDINGEVENT']._serialized_start=32880
  _globals['_SENDINGEVENT']._serialized_end=32910
  _globals['_SENDINGEVENTMSG']._serialized_start=32912
  _globals['_SENDINGEVENTMSG']._serialized_end=33012
  _globals['_SENDEVENTFAILURE']._serialized_start=33014
  _globals['_SENDEVENTFAILURE']._serialized_end=33032
  _globals['_SENDEVENTFAILUREMSG']._serialized_start=33034
  _globals['_SENDEVENTFAILUREMSG']._serialized_end=33142
  _globals['_FLUSHEVENTS']._serialized_start=33144
  _globals['_FLUSHEVENTS']._serialized_end=33157
  _globals['_FLUSHEVENTSMSG']._serialized_start=33159
  _globals['_FLUSHEVENTSMSG']._serialized_end=33257
  _globals['_FLUSHEVENTSFAILURE']._serialized_start=33259
  _globals['_FLUSHEVENTSFAILURE']._serialized_end=33279
  _globals['_FLUSHEVENTSFAILUREMSG']._serialized_start=33281
  _globals['_FLUSHEVENTSFAILUREMSG']._serialized_end=33393
  _globals['_TRACKINGINITIALIZEFAILURE']._serialized_start=33395
  _globals['_TRACKINGINITIALIZEFAILURE']._serialized_end=33440
  _globals['_TRACKINGINITIALIZEFAILUREMSG']._serialized_start=33442
  _globals['_TRACKINGINITIALIZEFAILUREMSG']._serialized_end=33568
  _globals['_RUNRESULTWARNINGMESSAGE']._serialized_start=33570
  _globals['_RUNRESULTWARNINGMESSAGE']._serialized_end=33650
  _globals['_RUNRESULTWARNINGMESSAGEMSG']._serialized_start=33652
  _globals['_RUNRESULTWARNINGMESSAGEMSG']._serialized_end=33774
  _globals['_DEBUGCMDOUT']._serialized_start=33776
  _globals['_DEBUGCMDOUT']._serialized_end=33802
  _globals['_DEBUGCMDOUTMSG']._serialized_start=33804
  _globals['_DEBUGCMDOUTMSG']._serialized_end=33902
  _globals['_DEBUGCMDRESULT']._serialized_start=33904
  _globals['_DEBUGCMDRESULT']._serialized_end=33933
  _globals['_DEBUGCMDRESULTMSG']._serialized_start=33935
  _globals['_DEBUGCMDRESULTMSG']._serialized_end=34039
  _globals['_LISTCMDOUT']._serialized_start=34041
  _globals['_LISTCMDOUT']._serialized_end=34066
  _globals['_LISTCMDOUTMSG']._serialized_start=34068
  _globals['_LISTCMDOUTMSG']._serialized_end=34164
  _globals['_RESOURCEREPORT']._serialized_start=34167
  _globals['_RESOURCEREPORT']._serialized_end=34403
  _globals['_RESOURCEREPORTMSG']._serialized_start=34405
  _globals['_RESOURCEREPORTMSG']._serialized_end=34509
# @@protoc_insertion_point(module_scope)
